{%- set master_pillar = pillar['salt']['master'] -%}
{%- set redis_config = '/etc/redis/salt.conf' -%}
{%- set redis_service = 'redis@salt' -%}

include:
  - salt.master

salt_master_extra_packages:
  pkg.installed:
    - names:
      - python3-pynetbox
      - python3-redis
      - redis
    - watch_in:
      - service: salt-master

# to-do: move Redis configuration to a formula
{{ redis_config }}:
  file.managed:
    - contents:
      - port 0
      - tcp-backlog 511
      - unixsocket /run/redis/salt.sock
      - unixsocketperm 460
      - timeout 0
      - supervised systemd
      - pidfile /run/redis/salt.pid
      - logfile /var/log/redis/salt.log
      - databases 1
      - dir /var/lib/redis/salt/
      - acllog-max-len 64
      - requirepass {{ master_pillar['cache.redis.password'] }}
    - user: root
    - group: redis
    - mode: 0640
    - require:
      - pkg: redis

/var/lib/redis/salt:
  file.directory:
    - user: redis
    - group: redis
    - mode: 0750
    - require:
      - pkg: redis

salt_redis_membership:
  group.present:
    - name: redis
    - addusers:
      - {{ master_pillar['user'] }}
    - require:
      - pkg: redis

salt_redis_service_enable:
  service.enabled:
    - name: {{ redis_service }}
    - require:
      - pkg: redis

salt_redis_service_start:
  service.running:
    - name: {{ redis_service }}
    - require:
      - pkg: redis
    - watch:
      - file: {{ redis_config }}
